declare 

v_field_id NUMBER(14);
v_dataspy_id NUMBER(14);
v_col_ord NUMBER;
DataSpyName varchar(50);
GridName varchar(20);
ExistingDataSpyId NUMBER(14);
ViewType varchar(20);

DataSpyExists number(1);
sequence_check varchar2(3);

QueryFieldExists number(1);

begin

DataSpyName := 'List of parts on material - AM';
GridName := 'LVMATLPART';
ViewType := 'LOV';

-- Cleanup

select count(*) into DataSpyExists
from r5dddataspy ds
inner join r5grid g on ds.dds_gridid = g.grd_gridid
where dds_ddspyname = DataSpyName
and g.grd_gridname = GridName
and rownum = 1;

IF DataSpyExists = 1 THEN

    select ds.dds_ddspyid into ExistingDataSpyId
    from r5dddataspy ds
    inner join r5grid g on ds.dds_gridid = g.grd_gridid
    where ds.dds_ddspyname = DataSpyName
    and g.grd_gridname = GridName;
    
    delete from r5queryfield where dqf_ddspyid = ExistingDataSpyId;
    delete from r5dddataspy where dds_ddspyid = ExistingDataSpyId;
END IF;

-- Insert new DataSpy and QueryField

r5o7.o7maxseq(v_dataspy_id, 'DDS', '1', sequence_check);

insert into R5dddataspy
(
    DDS_DDSPYNAME,
    DDS_DDSPYID,
    DDS_AUTORUN,
    DDS_SCOPE,
    DDS_ORGANIZATION,
    DDS_UPDATESTAMP,
    DDS_UPDATEBYUSER,
    DDS_CREATEDSTAMP,
    DDS_UPDATEABLE,
    DDS_FILTERSTRXML,
    DDS_SORTSTRXML,
    DDS_FIELDLIST,
    DDS_UPDATECOUNT,
    DDS_DISPLAYROW,
    DDS_OWNER,
    DDS_GRIDID,
    DDS_TYPE,
    DDS_DEFAULTFLAG,
    DDS_FIELDLIST_PORTLET,
    DDS_CLIENTROWS,
    DDS_PORTLETROWS,
    DDS_HINTS,
    DDS_BOTNAME,
    DDS_USERFILTER,
    DDS_SECURITYDATASPY,
    DDS_MEKEY
)
select
    DataSpyName,
    v_dataspy_id,
    '-',
    '-',
    DDS_ORGANIZATION,
    DDS_UPDATESTAMP,
    DDS_UPDATEBYUSER,
    DDS_CREATEDSTAMP,
    DDS_UPDATEABLE,
    DDS_FILTERSTRXML,
    DDS_SORTSTRXML,
    DDS_FIELDLIST,
    DDS_UPDATECOUNT,
    DDS_DISPLAYROW,
    DDS_OWNER,
    DDS_GRIDID,
    'UD',
    '-',
    DDS_FIELDLIST_PORTLET,
    DDS_CLIENTROWS,
    DDS_PORTLETROWS,
    DDS_HINTS,
    NULL,
    DDS_USERFILTER,
    DDS_SECURITYDATASPY,
    DDS_MEKEY
from R5dddataspy ds, r5grid g
where ds.dds_gridid = g.grd_gridid
and g.grd_gridname = GridName
and ds.dds_defaultflag = '+';

insert into r5queryfield
(
    DQF_DDSPYID,
    DQF_FIELDID,
    DQF_COLUMNWIDTH,
    DQF_COLUMNORDER,
    DQF_UPDATECOUNT,
    DQF_VIEWTYPE
)
select
    v_dataspy_id,
    DQF_FIELDID,
    DQF_COLUMNWIDTH,
    DQF_COLUMNORDER,
    DQF_UPDATECOUNT,
    DQF_VIEWTYPE
from r5queryfield q, R5dddataspy ds, r5grid g, r5gridfield gf
where q.dqf_ddspyid = ds.dds_ddspyid
AND ds.dds_gridid = g.grd_gridid
AND q.dqf_fieldid = gf.gfd_fieldid
AND gf.gfd_gridid = g.grd_gridid
and g.grd_gridname = GridName
and ds.dds_defaultflag = '+'
and q.dqf_viewtype = ViewType
order by g.grd_gridname, gf.GFD_BOTNUMBER;

-------------------------------------------------------------------------------
-- Add M.MFP_MANUFACTURER field
-------------------------------------------------------------------------------

select ddf_fieldid into v_field_id
from r5ddfield
where ddf_fieldid IN
(
    select gfd_fieldid
    from r5gridfield
    where gfd_gridid =
    (
        select grd_gridid
        from r5grid
        where grd_gridname = GridName
    )
)
AND UPPER(ddf_sourcename) = 'M.MFP_MANUFACTURER';

select max(DQF_COLUMNORDER)+1 into v_col_ord
from r5queryfield
where DQF_DDSPYID = v_dataspy_id;

select count(*) into QueryFieldExists
from r5queryfield
where dqf_ddspyid = v_dataspy_id
and dqf_fieldid = v_field_id
and dqf_viewtype = ViewType
and rownum = 1;

IF QueryFieldExists = 0 THEN
    insert into r5queryfield
    (
        DQF_DDSPYID,
        DQF_FIELDID,
        DQF_COLUMNWIDTH,
        DQF_COLUMNORDER,
        DQF_UPDATECOUNT,
        DQF_VIEWTYPE
    )
    values
    (
        v_dataspy_id,
        v_field_id,
        '120',
        v_col_ord,
        0,
        ViewType
    );
END IF;

-------------------------------------------------------------------------------
-- Add M.MFP_MANUFACTPART field
-------------------------------------------------------------------------------

select ddf_fieldid into v_field_id
from r5ddfield
where ddf_fieldid IN
(
    select gfd_fieldid
    from r5gridfield
    where gfd_gridid =
    (
        select grd_gridid
        from r5grid
        where grd_gridname = GridName
    )
)
AND UPPER(ddf_sourcename) = 'M.MFP_MANUFACTPART';

select max(DQF_COLUMNORDER)+1 into v_col_ord
from r5queryfield
where DQF_DDSPYID = v_dataspy_id;

select count(*) into QueryFieldExists
from r5queryfield
where dqf_ddspyid = v_dataspy_id
and dqf_fieldid = v_field_id
and dqf_viewtype = ViewType
and rownum = 1;

IF QueryFieldExists = 0 THEN
    insert into r5queryfield
    (
        DQF_DDSPYID,
        DQF_FIELDID,
        DQF_COLUMNWIDTH,
        DQF_COLUMNORDER,
        DQF_UPDATECOUNT,
        DQF_VIEWTYPE
    )
    values
    (
        v_dataspy_id,
        v_field_id,
        '120',
        v_col_ord,
        0,
        ViewType
    );
END IF;

-------------------------------------------------------------------------------
-- Add C.CAT_SUPPLIER field
-------------------------------------------------------------------------------

select ddf_fieldid into v_field_id
from r5ddfield
where ddf_fieldid IN
(
    select gfd_fieldid
    from r5gridfield
    where gfd_gridid =
    (
        select grd_gridid
        from r5grid
        where grd_gridname = GridName
    )
)
AND UPPER(ddf_sourcename) = 'C.CAT_SUPPLIER';

select max(DQF_COLUMNORDER)+1 into v_col_ord
from r5queryfield
where DQF_DDSPYID = v_dataspy_id;

select count(*) into QueryFieldExists
from r5queryfield
where dqf_ddspyid = v_dataspy_id
and dqf_fieldid = v_field_id
and dqf_viewtype = ViewType
and rownum = 1;

IF QueryFieldExists = 0 THEN
    insert into r5queryfield
    (
        DQF_DDSPYID,
        DQF_FIELDID,
        DQF_COLUMNWIDTH,
        DQF_COLUMNORDER,
        DQF_UPDATECOUNT,
        DQF_VIEWTYPE
    )
    values
    (
        v_dataspy_id,
        v_field_id,
        '120',
        v_col_ord,
        0,
        ViewType
    );
END IF;

commit;

end;

/