
declare
v_grid_name varchar2(6);
v_grid_id number(14);
v_grid_desc varchar2(40);
v_field_id number(14);
v_field_id_list VARCHAR2(1000);
v_grid_key_fields VARCHAR2(200);
v_dataspy_id number(14);
v_bot_number number(14);
v_field_source_name varchar2(100);
v_field_tag_name varchar2(100);
v_language VARCHAR2(2);
r5boilertexts_exists integer;
r5grid_exists integer;
r5functions_exists integer;
sequence_check varchar2(3);

begin

-------------------------------------------------------------------------------
-- Set custom grid name
-------------------------------------------------------------------------------

v_grid_name := 'WUJOBS'; 
v_language := '&1';

-------------------------------------------------------------------------------
-- Cleanup existing r5boilertexts
-------------------------------------------------------------------------------

select count(*) into r5boilertexts_exists
from r5boilertexts
where BOT_FUNCTION = v_grid_name
and rownum = 1;

IF r5boilertexts_exists = 1 THEN
	DELETE FROM r5boilertexts where BOT_FUNCTION = v_grid_name;
END IF;

-------------------------------------------------------------------------------
-- Cleanup existing r5grid and related data
-------------------------------------------------------------------------------

select count(*) into r5grid_exists
from r5grid
where GRD_GRIDNAME = v_grid_name
and rownum = 1;

IF r5grid_exists = 1 THEN
	DELETE FROM r5queryfield where DQF_DDSPYID in
    (
        select DDS_DDSPYID from R5dddataspy where DDS_GRIDID in
        (
            select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
        )
    );
	DELETE FROM r5usegridsysdefault where usd_dataspyid in
    (
        select DDS_DDSPYID from R5dddataspy where DDS_GRIDID in
        (
            select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
        )
    );
    DELETE FROM R5dddataspy WHERE DDS_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
    );
    DELETE FROM r5gridfield where GFD_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
    );
    DELETE FROM r5gridparam where GDP_GRIDID in
    (
        select grd_gridid from r5grid where GRD_GRIDNAME = v_grid_name
    );
    DELETE FROM r5grid WHERE GRD_GRIDNAME = v_grid_name;
END IF;


-------------------------------------------------------------------------------
-- Cleanup existing r5functions
-------------------------------------------------------------------------------

select count(*) into r5functions_exists
from r5functions
where FUN_CODE = v_grid_name
and rownum = 1;

IF r5functions_exists = 1 THEN
  DELETE FROM R5EXTMENULANG WHERE EML_EXTMENU IN (SELECT EMN_CODE FROM R5EXTMENUS WHERE EMN_FUNCTION = v_grid_name);
  DELETE FROM R5EXTMENUS WHERE EMN_FUNCTION = v_grid_name;
  DELETE FROM r5functions where FUN_CODE = v_grid_name;
END IF;


-------------------------------------------------------------------------------
--Insert r5functions
-------------------------------------------------------------------------------
INSERT INTO R5FUNCTIONS (FUN_CODE,FUN_DESC,FUN_CLASS,FUN_SUBTYPE,FUN_FILE,FUN_PUBLIC,FUN_SELECT,FUN_BACKGROUND,FUN_DIRSEL,FUN_SYSTEM,FUN_DISPLAYAP,FUN_DISPLAYFT,FUN_POPUPAP,FUN_POPUPFT,FUN_DESCCHANGED,FUN_CLASS_ORG,FUN_RS,FUN_LST,FUN_HDR,FUN_EWSREPORT,FUN_PRDDATASRC,FUN_EWSURLNEW,FUN_REPDISABLED,FUN_ADVREPT,FUN_MEKEY,FUN_EWSBTN)
 VALUES (v_grid_name,'Work Orders (AM)','WEBD','M','R5MENU','-','?','-','-','+','-','+','-','-','-','*','-','+','-','-','-','-','-','-','YN','-');

-------------------------------------------------------------------------------
-- Insert r5grid
-------------------------------------------------------------------------------

r5o7.o7maxseq(v_grid_id, 'GRD', '1', sequence_check);
INSERT INTO R5GRID (GRD_DESC,GRD_GRIDID,GRD_BASEQUERY,GRD_GRIDNAME,GRD_BOTFUNCTION,GRD_PORTLETFLAG,GRD_TAB,GRD_GRIDTYPE,GRD_OPTIMIZERON,GRD_DISTINCT,GRD_COMPLEX,GRD_ACTIVE,GRD_NOSCREENDESIGNER)
 VALUES ('Work Orders (AM)',v_grid_id,'FROM r5events e, r5ucodes u
    WHERE e.evt_rstatus IN (''Q'', ''R'', ''C'')
    AND e.evt_rtype IN (''JOB'', ''PPM'')
    AND u.uco_rentity = ''JBTP''
    and u.uco_code=e.evt_jobtype
    AND u.uco_rcode IN ( ''*'', ''BR'', ''ST'', ''PM'', ''CAL'' ,''RP'', ''MEC'')
    AND ((e.EVT_RSTATUS = ''C'' AND e.EVT_COMPLETED IS NOT NULL) OR (e.EVT_RSTATUS <> ''C''))',v_grid_name,v_grid_name,'-','+',2,'-','-','-','+','-');

-------------------------------------------------------------------------------
-- Insert r5dddataspy
-------------------------------------------------------------------------------

r5o7.o7maxseq(v_dataspy_id, 'DDS', '1', sequence_check);
INSERT INTO R5DDDATASPY (DDS_DDSPYNAME,DDS_DDSPYID,DDS_SCOPE,DDS_ORGANIZATION,DDS_CREATEDSTAMP,DDS_FILTERSTRXML,DDS_SORTSTRXML,DDS_OWNER,DDS_GRIDID,DDS_TYPE,DDS_DEFAULTFLAG,DDS_CLIENTROWS,DDS_BOTNAME,DDS_SECURITYDATASPY,DDS_MEKEY)
 VALUES ('All Records',v_dataspy_id,'-','*',sysdate,'<FILTERABLE />','<SORTABLE><SORT_ELEMENT ALIAS_NAME="datecreated" SEQNUM="1" TYPE="ASC"/><SORT_ELEMENT ALIAS_NAME="organization" SEQNUM="2" TYPE="ASC"/><SORT_ELEMENT ALIAS_NAME="workordernum" SEQNUM="3" TYPE="ASC"/></SORTABLE>','R5',v_grid_id,'SD','+',30,'DSNAME','-','YY');

-------------------------------------------------------------------------------
-- Insert the three base r5boilertexts
-- Note: You must also insert a r5boilertext record for each "grid field" (see below)
-------------------------------------------------------------------------------

INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,1,100,0,0,v_language,'List View','TB','1','LST','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,2,100,0,0,v_language,'Work Orders (AM)','F','1','UDG_HDRLABEL','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,3,100,0,0,v_language,'All Records','F','1','DSNAME','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,4,100,0,0,v_language,'workordernum','F','1','evt_code','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,5,100,0,0,v_language,'description','F','1','EVT_DESC','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,6,100,0,0,v_language,'equipment','F','1','evt_object','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,7,100,0,0,v_language,'evt_object_org','F','1','evt_object_org','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,8,100,0,0,v_language,'equipmentdesc','F','1','equipmentdesc','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,9,100,0,0,v_language,'equipmenttypedesc','F','1','equipmenttypedesc','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,10,100,0,0,v_language,'organization','F','1','organization','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,11,100,0,0,v_language,'department','F','1','department','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,12,100,0,0,v_language,'schedstartdate','F','1','schedstartdate','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,13,100,0,0,v_language,'schedenddate','F','1','schedenddate','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,14,100,0,0,v_language,'workorderstatus','F','1','workorderstatus','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,15,100,0,0,v_language,'assignedto','F','1','assignedto','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,18,100,0,0,v_language,'createdby','F','1','createdby','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,19,100,0,0,v_language,'requeststart','F','1','requeststart','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,20,100,0,0,v_language,'datecompleted','F','1','datecompleted','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,21,100,0,0,v_language,'woclass','F','1','woclass','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,22,100,0,0,v_language,'priority','F','1','priority','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,23,100,0,0,v_language,'prioritydesc','F','1','prioritydesc','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,24,100,0,0,v_language,'workorderstatus_display','F','1','workorderstatus_display','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,25,100,0,0,v_language,'problemcode','F','1','problemcode','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,26,100,0,0,v_language,'causecode','F','1','causecode','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,27,100,0,0,v_language,'actioncode','F','1','actioncode','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,28,100,0,0,v_language,'failurecode','F','1','failurecode','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,29,100,0,0,v_language,'startdate','F','1','startdate','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,30,100,0,0,v_language,'location','F','1','location','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,31,100,0,0,v_language,'evt_rstatus','F','1','evt_rstatus','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,32,100,0,0,v_language,'evt_updatedby','F','1','evt_updatedby','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,33,100,0,0,v_language,'recordid','F','1','evt_updatecount','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,34,100,0,0,v_language,'updateddate','F','1','updateddate','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,35,100,0,0,v_language,'datecreated','F','1','datecreated','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,36,100,0,0,v_language,'workordertype','F','1','workordertype','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,37,100,0,0,v_language,'standardworkorder','F','1','standardworkorder','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,38,100,0,0,v_language,'classorg','F','1','classorg','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,39,100,0,0,v_language,'evt_parent','F','1','evt_parent','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,40,100,0,0,v_language,'evt_ppm','F','1','evt_ppm','10000',sysdate,'-');
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,41,100,0,0,v_language,'evt_location_org','F','1','evt_location_org','10000',sysdate,'-'); 
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,42,100,0,0,v_language,'evt_safety','F','1','evt_safety','10000',sysdate,'-'); 
INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_POOL,BOT_CREATED,BOT_CLONED)
 VALUES (v_grid_name,43,100,0,0,v_language,'evt_objcriticality','F','1','evt_objcriticality','10000',sysdate,'-'); 

-------------------------------------------------------------------------------
-- Copy the R5BOILERTEXTS for each of the languages in the R5LANGINST
-------------------------------------------------------------------------------

INSERT INTO R5BOILERTEXTS (BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,BOT_LANG,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_FLD2,BOT_PRTP,BOT_LVCR,BOT_ADLEN,BOT_POOL,BOT_CHANGED,BOT_DISPLAY,BOT_CREATED,BOT_CLONED)
SELECT BOT_FUNCTION,BOT_NUMBER,BOT_LENGTH,BOT_XPOS,BOT_YPOS,LIN_CODE,BOT_TEXT,BOT_DEST,BOT_PAGE,BOT_FLD1,BOT_FLD2,BOT_PRTP,BOT_LVCR,BOT_ADLEN,BOT_POOL,BOT_CHANGED,BOT_DISPLAY,BOT_CREATED,BOT_CLONED
FROM R5BOILERTEXTS, R5LANGINST
WHERE
BOT_LANG = v_language AND BOT_FUNCTION = v_grid_name AND lin_code <> v_language;

-------------------------------------------------------------------------------
-- Insert r5ddfield, r5gridfield, r5queryfield for each grid field
-------------------------------------------------------------------------------

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := LTRIM(RTRIM(v_field_id));
v_grid_key_fields :=  LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.evt_code','VARCHAR','LVWORK;gridtagname=workorder','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,4,'TEXT','workordernum','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',1,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'R5O7.O7GET_DESC(:parameter.language, ''EVNT'', e.evt_code || ''#'' || e.evt_org, '''', '''')','MIXVARCHAR','','');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,5,'TEXT','description','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',2,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.evt_object','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,6,'TEXT','equipment','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',3,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.evt_object_org','VARCHAR','LVORGALL;gridtagname=organization','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,7,'TEXT','equipmentorg','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',4,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'R5O7.O7GET_DESC(:parameter.language,''OBJ'', e.evt_object || ''#'' || e.evt_object_org,'''', '''')','MIXVARCHAR','','');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,8,'TEXT','equipmentdesc','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',5,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'R5O7.O7GET_DESC(:parameter.language,''UCOD'', e.evt_obtype,''OBTP'', '''')','MIXVARCHAR','','');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,9,'TEXT','equipmenttypedesc','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',6,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.evt_org','VARCHAR','LVSORGALL;gridtagname=organization','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,10,'TEXT','organization','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',7,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.EVT_MRC','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,11,'TEXT','department','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',8,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.EVT_TARGET','DATE','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,12,'TEXT','schedstartdate','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',9,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.EVT_SCHEDEND','DATE','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,13,'TEXT','schedenddate','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',10,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.EVT_STATUS','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,14,'TEXT','workorderstatus','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',11,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.EVT_PERSON','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,15,'TEXT','assignedto','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',12,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.EVT_ENTEREDBY','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,18,'TEXT','createdby','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',13,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.EVT_REQUESTSTART','DATE','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,19,'TEXT','requeststart','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',14,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.evt_completed','DATE','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,20,'TEXT','datecompleted','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',15,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.evt_class','VARCHAR','LVCLASALL;parameter.rentity=EVNT,gridtagname=class','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,21,'TEXT','woclass','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',16,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.evt_priority','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,22,'TEXT','priority','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',17,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'R5O7.O7GET_DESC(:parameter.language,''UCOD'', e.evt_priority,''JBPR'', '''')','MIXVARCHAR','','');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,23,'TEXT','prioritydesc','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',18,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'R5O7.O7GET_DESC(:parameter.language,''UCOD'', e.evt_status,''EVST'', '''')','MIXVARCHAR','','');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,24,'TEXT','workorderstatus_display','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',19,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.EVT_REQM','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,25,'TEXT','problemcode','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',20,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.EVT_CAUSE','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,26,'TEXT','causecode','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',21,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.EVT_ACTION','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,27,'TEXT','actioncode','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',22,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.EVT_FAILURE','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,28,'TEXT','failurecode','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',23,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.EVT_START','DATETIME','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,29,'TEXT','startdate','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',24,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.EVT_LOCATION','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,30,'TEXT','location','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',25,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.EVT_RSTATUS','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,31,'TEXT','evt_rstatus','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',26,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.EVT_UPDATEDBY','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,32,'TEXT','evt_updatedby','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',27,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.EVT_UPDATECOUNT','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,33,'TEXT','recordid','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',28,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.EVT_UPDATED','DATETIME','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,34,'TEXT','updateddate','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',29,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.evt_created','DATETIME','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,35,'TEXT','datecreated','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',30,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'UCO_CODE','VARCHAR','','R5MP2WOTYPE_EXT');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,36,'TEXT','workordertype','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',31,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'EVT_STANDWORK','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,37,'TEXT','standardworkorder','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',32,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'EVT_CLASS_ORG','VARCHAR','LVORGALL;gridtagname=organization','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,38,'TEXT','classorg','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',33,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.evt_parent','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,39,'TEXT','evt_parent','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',34,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'e.evt_ppm','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,40,'TEXT','evt_ppm','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',35,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'evt_location_org','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,41,'TEXT','evt_location_org','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',36,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'evt_safety','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,42,'TEXT','evt_safety','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',38,'LIST');

r5o7.o7maxseq(v_field_id, 'DDF', '1', sequence_check);
v_field_id_list := v_field_id_list || ',' || LTRIM(RTRIM(v_field_id));
INSERT INTO R5DDFIELD (DDF_FIELDID,DDF_SOURCENAME,DDF_DATATYPE,DDF_LVGRID,DDF_TABLENAME)
 VALUES (v_field_id,'evt_objcriticality','VARCHAR','','R5EVENTS');
INSERT INTO R5GRIDFIELD (GFD_FIELDID,GFD_GRIDID,GFD_BOTFUNCTION,GFD_BOTNUMBER,GFD_CONTROLTYPE,GFD_TAGNAME,GFD_FIELDTYPE,GFD_OCCURRENCE,GFD_HEADERLOCATION)
 VALUES (v_field_id,v_grid_id,v_grid_name,43,'TEXT','evt_objcriticality','n',1,'n');
INSERT INTO R5QUERYFIELD (DQF_DDSPYID,DQF_FIELDID,DQF_COLUMNWIDTH,DQF_COLUMNORDER,DQF_VIEWTYPE)
 VALUES (v_dataspy_id,v_field_id,'180',39,'LIST');

-------------------------------------------------------------------------------
-- Insert r5gridparam
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- Setup field keys on r5grid
-------------------------------------------------------------------------------

update r5grid set 
grd_keyfields = v_grid_key_fields, 
grd_filterablelist = v_field_id_list,
grd_sortablelist = v_field_id_list,
grd_displayablelist = v_field_id_list
where grd_gridid = v_grid_id;

commit;

end;

/
